@@ -96,16 +96,16 @@
 #'     specified by the user, default name is `Variant'.} 
 #'    \item{log10_BF}{It provides the log10(Bayes factor) produced by CPBayes that measures
 #'     the evidence of the overall pleiotropic association.}
-#'    \item{PPNA}{It provides the posterior probability of null association produced by
-#'     CPBayes (a Bayesian analog of the p-value) which is another measure of the evidence
+#'    \item{locFDR}{It provides the local false discovery rate (posterior probability of null association) produced by
+#'     CPBayes (a Bayesian analog of the p-value) which is a measure of the evidence
 #'      of aggregate-level pleiotropic association. Bayes factor is adjusted for prior odds, but
- #'      PPNA is solely a function of posterior odds. PPNA can sometimes be significantly small
- #'      indicating an association, but log10_BF may not. Hence, always check both log10_BF and PPNA.}
+ #'      locFDR is solely a function of posterior odds. locFDR can sometimes be significantly small
+ #'      indicating an association, but log10_BF may not. Hence, always check both log10_BF and locFDR.}
 #'    \item{subset}{A data frame providing the optimal subset of associated/non-null traits
 #'     along with their trait-specific posterior probability of association (PPAj) and direction
 #'      of associations. It is NULL if no phenotype is selected by CPBayes.}
 #'    \item{important_traits}{It provides the traits which yield a trait-specific posterior
-#'     probability of association (PPAj) > 25\%. Even if a phenotype is not selected in the
+#'     probability of association (PPAj) > 20\%. Even if a phenotype is not selected in the
 #'    optimal subset of non-null traits, it can produce a non-negligible value of
 #'     trait-specific posterior probability of association. We note that `important_traits'
 #'      is expected to include the traits already contained in `subset'. It provides the
@@ -126,10 +126,7 @@
 #'       standard error, credible interval (lower and upper limits) of the true odds 
 #'        ratio corresponding to each trait.}
 #'        
-#' @references Arunabha Majumdar, Tanushree Haldar, Sourabh Bhattacharya, John Witte.
-#'  An efficient Bayesian meta-analysis 
-#'  approach for studying cross-phenotype genetic associations (submitted), available
-#'  at: http://biorxiv.org/content/early/2017/01/18/101543.
+#' @references Majumdar A, Haldar T, Bhattacharya S, Witte JS (2018) An efficient Bayesian meta analysis approach for studying cross-phenotype genetic associations. PLoS Genet 14(2): e1007139.
 #'  
 #' @seealso \code{\link{cpbayes_uncor}}, \code{\link{cpbayes_cor}}, \code{\link{forest_cpbayes}}, \code{\link{estimate_corln}}
 #' 
@@ -151,7 +148,7 @@
 
      genetic_variant <- mcmc_output$variantName
      log10_BF <- mcmc_output$log10_BF
-     PPNA <- mcmc_output$PPNA
+     PPNA <- mcmc_output$locFDR
      subset <- mcmc_output$subset
      important_phenos <- mcmc_output$important_traits
    
@@ -223,7 +220,7 @@
      poste_summary_OR = data.frame( traits = traitNames, poste_mean = poste_mean_OR, poste_median = poste_median_OR, 
                         lCl = CI_OR_l, uCl = CI_OR_u, stringsAsFactors = FALSE)
     
-     data = list( variantName = genetic_variant, log10_BF = log10_BF, PPNA = PPNA, subset = optimal_subset, 
+     data = list( variantName = genetic_variant, log10_BF = log10_BF, locFDR = PPNA, subset = optimal_subset, 
             important_traits = important_phenos, traitNames = traitNames, PPAj = asso_prob, 
             poste_summary_beta = poste_summary_beta, poste_summary_OR = poste_summary_OR )
  }
@@ -244,22 +241,22 @@
 #'  or \code{\link{cpbayes_cor}}. No default is specified. See the example below.
 #' @param level A numeric value. (1-level)\% confidence interval of the unknown true genetic effect (beta/log(odds ratio))
 #'   on each trait is plotted in the forest plot. Default choice is 0.05.
+#' @param PPAj_cutoff A numeric value. It's a user-specified threshold of PPAj (trait-specific posterior probability
+#'   of association). Only those traits having PPAj values above this cut-off are included in the forest plot. So, the choice of 
+#'   this variable as '0.0' includes all traits in the forest plot. Default is 0.01.
 #' @return The output produced by this function is a diagram file in .pdf format. The details of the diagram are as follows: 
 #'    \item{file_name}{The pdf file is named after the genetic variant. So, if the argument `Variant'
 #'    in \code{\link{cpbayes_uncor}} or \code{\link{cpbayes_cor}} is specified as 'rs1234', the figure file is named as rs1234.pdf.} 
-#'    \item{Title}{At the top of the figure, variant name and the corresponding log10(Bayes factor) and PPNA produced by CPBayes is stated.}
+#'    \item{Title}{At the top of the figure, variant name and the corresponding locFDR and log10(Bayes factor) produced by CPBayes is stated.}
 #'    \item{Column1}{First column in the figure specifies the name of the phenotypes.}
-#'    \item{Column2}{Second column provides the trait-specific univariate association p-values for each trait.}
+#'    \item{Column2}{Second column provides the trait-specific univariate association p-value for a trait.}
 #'    \item{Column3}{Third column provides the trait-specific posterior probability of association (PPAj) produced by CPBayes.}
 #'    \item{Column4}{Fourth column states whether a phenotype was selected in the optimal subset of associated/non-null traits
 #'    detected by CPBayes. If a phenotype was not selected, selected and positively associated, selected and negatively associated,
-#'     its association status is stated as null, positive, and negative, respectively.}
-#'    \item{Column5}{In the right section of the figure, the primary eatimate and confidence interval of the beta/log(odds ratio) parameter for
-#'     each trait is plotted.}
-#' @references Arunabha Majumdar, Tanushree Haldar, Sourabh Bhattacharya, John Witte.
-#'  An efficient Bayesian meta-analysis 
-#'  approach for studying cross-phenotype genetic associations (submitted), available
-#'  at: http://biorxiv.org/content/early/2017/01/18/101543.
+#'     its association status is stated as null, positive and negative, respectively.}
+#'    \item{Column5}{In the right section of the figure, the primary eatimate and confidence interval of the beta/log odds ratio parameter for
+#'     a trait is plotted.}
+#' @references Majumdar A, Haldar T, Bhattacharya S, Witte JS (2018) An efficient Bayesian meta analysis approach for studying cross-phenotype genetic associations. PLoS Genet 14(2): e1007139.
 #'  
 #' @seealso \code{\link{cpbayes_uncor}}, \code{\link{cpbayes_cor}}, \code{\link{post_summaries}}, \code{\link{estimate_corln}}
 #' 
@@ -273,8 +270,8 @@
 #' forest_cpbayes(result, level = 0.05) 
 #' 
 #' @export
-forest_cpbayes <- function(mcmc_output, level = 0.05){
-   
+forest_cpbayes <- function(mcmc_output, level = 0.05, PPAj_cutoff = 0.01){
+
    result <- mcmc_output
    betahat <- result$auxi_data$betahat
    se <- result$auxi_data$se
@@ -282,56 +279,69 @@ forest_cpbayes <- function(mcmc_output, level = 0.05){
    traits <- summ$traitNames                               ## phenotypes
    K <- length(traits)                                     ## number of traits
    selection <- rep("null", K)                             ## if no trait is selected
-   
+
    if(is.null(summ$subset) == FALSE){
      selected_traits <- summ$subset$traits
      select_trait_posi <- match(selected_traits, traits)
      direction <- summ$subset$direction
      selection[select_trait_posi] <- direction
    }
-   
+
    upper_alfa <- abs(qnorm( (level/2), 0,1))
    shift <- upper_alfa*se
    lowCIbeta <- betahat - shift                            ## lower confidence interval of beta
    upCIbeta <- betahat + shift                             ## upper confidence interval of 
    pvalues <- pchisq( (betahat/se)^2, df=1, lower.tail=F )
-   
+
    for(j in 1:K){
      x <- pvalues[j]
      count <- 0
      while(x < 1){ x <- 10*x; count <- count+1 }
      pvalues[j] <- round(pvalues[j], digits = count)     ## or, digits = count 
    }
-   
+
+   PPAj <- summ$PPAj$PPAj
+   select = which(PPAj > PPAj_cutoff)
    PPAj <- round(100*summ$PPAj$PPAj, digits = 1)
+
    PPAj <- paste(as.character(PPAj), "%", sep = "")
    labeltext <- data.frame( Trait = traits, Pvalue = as.character(pvalues), PPAj = PPAj, selection = selection, stringsAsFactors = FALSE )
-   
+
    df_names <- data.frame( Trait = "Trait", Pvalue = "pvalue", PPAj = "PPAj", selection = "association", stringsAsFactors=F)
    labeltext = rbind(df_names,labeltext)
-   
+
    betahat <- c(NA, betahat)
    lowCIbeta <- c(NA, lowCIbeta)
    upCIbeta <- c(NA, upCIbeta)
-   
-   
+
+
    log10BF <- round(summ$log10_BF, digits = 2)
-   PPNA <- summ$PPNA
+   PPNA <- summ$locFDR
    x <- PPNA
    count <- 0
    while(x < 1){ x <- 10*x; count <- count+1 }
    PPNA <- round(PPNA, digits = count+1)
-   
-   title <- summ$variantName
-   pdffile <- paste(title, ".pdf", sep = "")
-   title <- paste("Pleiotropy at ", title, ": log10BF = ", log10BF, ", PPNA = ", PPNA, sep = "")   ##  "PPNA = ", PPNA,
-   pdf(pdffile)
-   
-   forestplot(labeltext, betahat, lowCIbeta, upCIbeta, zero = 0, lineheight = "auto", boxsize = 0.12, 
-              xlab = "Estimate and CI of log(OR)", col = fpColors(lines="red", box="darkred"),
-              title = title, new_page = FALSE)
-   
-   dev.off()
- }
- 
+
+
+
+   if(length(select) > 0){
+
+     select <- select+1
+     select <- c(1,select)
+     title <- summ$variantName
+     pdffile <- paste(title, ".pdf", sep = "")
+     title <- paste("Pleiotropy at ", title, ": locFDR = ", PPNA, ", log10BF = ", log10BF, sep = "")   ##  "PPNA = ", PPNA,
+     pdf(pdffile)
+
+     forestplot(labeltext[select, ], betahat[select], lowCIbeta[select], upCIbeta[select],
+                zero = 0, lineheight = "auto", boxsize = 0.12, xlab = "Estimate and CI of log(OR)",
+                col = fpColors(lines="red", box="darkred"), title = title, new_page = FALSE)
+     # boxsize = 0.12,
+     dev.off()
+   }else{
+     print("Forest plot not created, because no trait has a PPA_j value above the threshold specified.")
+   }
+
+}
+
  
